==> Bchron_3.1.2.tar.gz: Bchron/R/Bchron-internal.R <==
.onAttach <-
function(libname, pkgname) {
    Bchronver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
                      fields="Version")
    message(paste(pkgname, Bchronver))
    message("Type help(Bchron) for installation instructions or Bchronmenu() to get started.")
}

.Random.seed <-
c(403L, 352L, 223866561L, -632080861L, -1036516781L, 1737880075L, 
-1492361981L, -2059883781L, 1079127716L, -1503832986L, 2061017207L, 
-859694335L, -1409136194L, 1649210092L, -2017493071L, -1793894025L, 
-1114270734L, 53065304L, 1495889219L, -645350597L, 2016124966L, 
1543918380L, -1344709263L, 1999003966L, 1519438465L, 451888815L, 
-1519297779L, -160118812L, -1013519042L, 2122212558L, 273290883L, 
-1918121038L, 544272065L, 1696461825L, 703172473L, -1594715370L, 
1050227625L, 628897153L, -908277660L, -1620550391L, 1110124666L, 
-334986930L, -357093297L, -320955704L, 168666491L, -609543542L, 
1709646367L, -2021091715L, 1462745535L, -75575883L, 75588914L, 
58864156L, 1902656218L, -1614385722L, 2019436141L, -1110349252L, 
-1892991435L, 479888825L, -145575365L, -1204990225L, 781444092L, 
-1204977474L, 1381606527L, -534230560L, 75848487L, -256466953L, 
2010511600L, 694266461L, -1159928472L, -1542476504L, -1966671385L, 
16364830L, -1209517071L, 372081134L, 1514534432L, 1304179174L, 
30394936L, -1793919549L, 1352281513L, 404785149L, -398240693L, 
-591213777L, -62667529L, -941309622L, 1026918433L, 1272621549L, 
-686480486L, 413921396L, -285880039L, -1783700740L, 1837256903L, 
-838689476L, 846524240L, 984774594L, 1152837809L, 1496486047L, 
-869343217L, 558428497L, -576764857L, -471199315L, 522045668L, 
218333730L, -623377778L, 1110838749L, -1911962828L, -111876775L, 
-502631002L, 1907443857L, 1336701514L, 2001550022L, 53357025L, 
612526419L, 633083445L, -1386388131L, -1052178974L, 1930368850L, 
-1295962947L, 24727757L, 765044603L, 166560414L, -1144839251L, 
-2144684141L, -768463347L, -864160327L, 2034528062L, 3706071L, 
1373787116L, -1528657122L, -1446441144L, 1360277495L, -1016077210L, 
-636110017L, -69396322L, -1957900326L, -771975968L, -171885918L, 
-1391705869L, -1209523747L, -477508908L, -1237697531L, 1493494373L, 
1381090349L, 2093094123L, -1442221453L, 21885650L, 1211534424L, 
-32357212L, 1331182020L, -279953541L, -917146663L, -1487419038L, 
-1435949436L, 2065583532L, -1146313798L, 34842610L, 244415835L, 
120533182L, -124186086L, 2078520616L, -1697455223L, 1663036306L, 
139251640L, -1654890132L, 863510721L, 1547800977L, -1899028789L, 
-929556828L, -124614092L, 997561935L, 1146627433L, 1377117369L, 
-20212883L, -794742770L, 845828600L, -1605808051L, 86315367L, 
-572640374L, -1131756888L, 246821523L, 860193811L, -545892030L, 
1895221555L, -1288511752L, -1846728515L, -850143216L, 377705349L, 
-356744280L, -919675017L, -2077907563L, -1304144247L, -1188955356L, 
-1186343870L, -2133325802L, -371526377L, 1315859144L, 743750466L, 
-1700468919L, -1325859434L, -1081468322L, -2145188355L, 2132439831L, 
1394629776L, 154869869L, 308611124L, 578792461L, 1583990973L, 
138527081L, -996257448L, -1492835584L, -678218647L, 1627694008L, 
1163594900L, 126149236L, 734588759L, -507950411L, -112085757L, 
66617509L, -1864371317L, -1889018354L, -712690723L, 1629179878L, 
-823342466L, -1871120952L, -1577703810L, -1336129281L, 932347700L, 
1388621583L, -469043706L, -1285091933L, 640453283L, 514770224L, 
-1156521588L, -86366490L, -1078766074L, -1087762543L, -735096980L, 
-1549173331L, 816892173L, -342653233L, -2039460811L, -1027420128L, 
-1814111364L, -1060938959L, 742913848L, -2139704116L, 230763807L, 
-1217569767L, 1247650849L, 1817837178L, 33073098L, -1287214530L, 
1376096089L, 30555000L, 880234241L, -132679108L, 2023576024L, 
-1968308935L, 350896305L, -350546295L, -1339707523L, -1996986827L, 
-750069346L, 2019110153L, 2010507683L, 1499114858L, 1221034340L, 
-55201954L, -27009123L, -636257817L, 169507249L, 693898591L, 
760623720L, -909425639L, 1705754829L, -1313442647L, -1581135430L, 
16673697L, -1267958419L, 1332689002L, -1158926668L, 495721563L, 
244051347L, -1514183753L, -639815868L, -1781542556L, -692156919L, 
2051887294L, -1914122214L, -383356852L, 1622339695L, -592502599L, 
-556629257L, 532008048L, -281553887L, -768445151L, -352434666L, 
-571885303L, 1103352084L, 1688500531L, -1361078092L, 27286100L, 
-219582676L, 1144261085L, 175701629L, -326296560L, 505864082L, 
979434262L, -1459028703L, 1004276016L, -103691272L, -1380152717L, 
103978604L, 775878565L, -1512848713L, 1380214743L, 195416670L, 
-64905306L, -2061452680L, -2059069998L, 1751878340L, -901786959L, 
-1808832951L, 333730595L, 155051652L, -114136432L, -1792807040L, 
-669065844L, -40602418L, 1888486298L, 221740459L, -776216693L, 
-759007236L, -2107020284L, -1064059511L, 1282093151L, 1288083859L, 
828371778L, -477286234L, 1048762045L, -1964138693L, -986068094L, 
1702791140L, -701726756L, 1497120837L, 1341752833L, 1941426743L, 
679892623L, -69036935L, 1042913176L, -707092306L, 1778589148L, 
-1203408296L, 165002193L, 66663045L, -765673841L, -670037979L, 
-2061012313L, -521231938L, -1458748160L, 510890047L, 517006858L, 
-1106600160L, 1697798857L, 1374654699L, -1329524735L, 147765279L, 
-54923264L, 335215122L, -784761704L, 1008955615L, 2098139462L, 
-1490175118L, -1406571085L, -1152159470L, -2116290393L, 973135784L, 
-407846339L, 91247076L, -1270777129L, 520392520L, 935330501L, 
1214726339L, 1759434859L, 914695131L, 575876380L, 185113183L, 
-1803307715L, -787346694L, -1944422115L, -911950047L, -1974450029L, 
-484550235L, -735767970L, 419724140L, 82738512L, -21269283L, 
1481364191L, 2052612746L, 409598710L, 1375600209L, 1805068679L, 
-1218769587L, -430995374L, -743769972L, 1416344157L, -894912681L, 
-953784357L, 1226488055L, -1708139998L, 1098915931L, 753725969L, 
105943479L, 919752384L, -1394184458L, -2083022837L, 1142405617L, 
-852560090L, 1614587943L, -1632540004L, 782503124L, 1359511283L, 
1802420419L, 1518930069L, -889840683L, 1792387250L, 1628877863L, 
-1035409712L, 89630224L, -747760297L, -1930525421L, 437973357L, 
2002557563L, -258998554L, 2029350061L, -985002193L, -1149315111L, 
-955951243L, -1745906808L, -1189428597L, 1432303109L, 1133303885L, 
1318201162L, 42941320L, 1107944820L, -962571238L, 2137510837L, 
1129487240L, 1637756575L, 308593884L, -2004056331L, 94376351L, 
-1310829101L, -761732610L, -42306764L, -56685990L, -1178321163L, 
-1303085749L, 1671878345L, -936552788L, -867833460L, 704830697L, 
1174726580L, 1566560463L, -726527240L, 607730759L, 2044821405L, 
1683011630L, 1306045960L, 747348418L, -1995048319L, 67753504L, 
1850386365L, -878540578L, 2030985621L, 1599574666L, 1130707121L, 
-1061888609L, -1533811533L, -1686609013L, -1305465928L, -1793764883L, 
1366209685L, 1020821247L, 811945970L, 516856759L, 1645604082L, 
-723481138L, 2054878228L, 1055244342L, 1267906174L, -149484207L, 
1893026618L, 2066225108L, -636361509L, 1204288031L, 1808071176L, 
2123356843L, -164362183L, 1340310464L, 1494503539L, 1292431590L, 
-1679366373L, 1139788819L, 1979839436L, 1779548790L, 1524419541L, 
1626372886L, 527265140L, 743859962L, 1886786557L, 1414284343L, 
-1602009995L, -960203316L, 386460461L, 382314113L, 488058564L, 
54251097L, 731916569L, 1633358446L, 276561965L, 573497844L, -1825530218L, 
1468256900L, -274279787L, -2105979127L, -1383909277L, -921915299L, 
-2089059664L, -1207012329L, -814324213L, 1318809738L, 1428891438L, 
1125095688L, -2066055560L, -1483592116L, 19572403L, 1016215100L, 
1888612105L, 1756422121L, -1696848131L, 1474030445L, 1633672810L, 
-1452695056L, -2101447495L, 757317618L, 502427844L, 566802492L, 
-1780421717L, -59374165L, -678664992L, -828266472L, 323800610L, 
212389631L, -833994011L, -1850652137L, 2082431238L, 61751832L, 
1200193220L, 1602757833L, -767376574L, 1324433665L, -324293114L, 
2117710490L, 1488867325L, -572190665L, 1354671303L, -696552212L, 
644262991L, -1508628111L, 987826153L, -1036270614L, 1762206296L, 
1565511850L, -14802381L, -1861485218L, 1229093286L, 1980935575L, 
274036669L, 1233283696L, 1545561561L, -572038552L, 935617470L, 
-781247662L, 128028723L, -1692139865L, -1871557370L, -548746370L, 
5436478L, 1443402536L, -1287344844L, 1516714978L, 464400252L, 
-592344731L, -1954630241L, -236331062L, -1053459219L, -80375436L, 
1592667359L, 122837253L, -1336100918L, -100559412L, -403105056L, 
1312256341L, 1465149208L, -1752641116L, -1932836360L, -1699791064L, 
162207872L, 1206369594L, -238862102L, -1880708909L, 1448277362L, 
1280673216L, 1874847879L, -1656130043L, -1393676549L, 1262048917L, 
-545449244L, -1544360730L, -760106086L, -1824261011L, 974734731L, 
-686111072L, -1525639249L, -808643128L, -2016756407L)

==> Bchron_3.1.5.tar.gz: Bchron/R/Bchron-internal.R <==
.onAttach <-
function(libname, pkgname) {
    Bchronver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname), 
                      fields="Version")
    packageStartupMessage(paste(pkgname, Bchronver,"\n"))
}

.Random.seed <-
c(403L, 352L, 223866561L, -632080861L, -1036516781L, 1737880075L, 
-1492361981L, -2059883781L, 1079127716L, -1503832986L, 2061017207L, 
-859694335L, -1409136194L, 1649210092L, -2017493071L, -1793894025L, 
-1114270734L, 53065304L, 1495889219L, -645350597L, 2016124966L, 
1543918380L, -1344709263L, 1999003966L, 1519438465L, 451888815L, 
-1519297779L, -160118812L, -1013519042L, 2122212558L, 273290883L, 
-1918121038L, 544272065L, 1696461825L, 703172473L, -1594715370L, 
1050227625L, 628897153L, -908277660L, -1620550391L, 1110124666L, 
-334986930L, -357093297L, -320955704L, 168666491L, -609543542L, 
1709646367L, -2021091715L, 1462745535L, -75575883L, 75588914L, 
58864156L, 1902656218L, -1614385722L, 2019436141L, -1110349252L, 
-1892991435L, 479888825L, -145575365L, -1204990225L, 781444092L, 
-1204977474L, 1381606527L, -534230560L, 75848487L, -256466953L, 
2010511600L, 694266461L, -1159928472L, -1542476504L, -1966671385L, 
16364830L, -1209517071L, 372081134L, 1514534432L, 1304179174L, 
30394936L, -1793919549L, 1352281513L, 404785149L, -398240693L, 
-591213777L, -62667529L, -941309622L, 1026918433L, 1272621549L, 
-686480486L, 413921396L, -285880039L, -1783700740L, 1837256903L, 
-838689476L, 846524240L, 984774594L, 1152837809L, 1496486047L, 
-869343217L, 558428497L, -576764857L, -471199315L, 522045668L, 
218333730L, -623377778L, 1110838749L, -1911962828L, -111876775L, 
-502631002L, 1907443857L, 1336701514L, 2001550022L, 53357025L, 
612526419L, 633083445L, -1386388131L, -1052178974L, 1930368850L, 
-1295962947L, 24727757L, 765044603L, 166560414L, -1144839251L, 
-2144684141L, -768463347L, -864160327L, 2034528062L, 3706071L, 
1373787116L, -1528657122L, -1446441144L, 1360277495L, -1016077210L, 
-636110017L, -69396322L, -1957900326L, -771975968L, -171885918L, 
-1391705869L, -1209523747L, -477508908L, -1237697531L, 1493494373L, 
1381090349L, 2093094123L, -1442221453L, 21885650L, 1211534424L, 
-32357212L, 1331182020L, -279953541L, -917146663L, -1487419038L, 
-1435949436L, 2065583532L, -1146313798L, 34842610L, 244415835L, 
120533182L, -124186086L, 2078520616L, -1697455223L, 1663036306L, 
139251640L, -1654890132L, 863510721L, 1547800977L, -1899028789L, 
-929556828L, -124614092L, 997561935L, 1146627433L, 1377117369L, 
-20212883L, -794742770L, 845828600L, -1605808051L, 86315367L, 
-572640374L, -1131756888L, 246821523L, 860193811L, -545892030L, 
1895221555L, -1288511752L, -1846728515L, -850143216L, 377705349L, 
-356744280L, -919675017L, -2077907563L, -1304144247L, -1188955356L, 
-1186343870L, -2133325802L, -371526377L, 1315859144L, 743750466L, 
-1700468919L, -1325859434L, -1081468322L, -2145188355L, 2132439831L, 
1394629776L, 154869869L, 308611124L, 578792461L, 1583990973L, 
138527081L, -996257448L, -1492835584L, -678218647L, 1627694008L, 
1163594900L, 126149236L, 734588759L, -507950411L, -112085757L, 
66617509L, -1864371317L, -1889018354L, -712690723L, 1629179878L, 
-823342466L, -1871120952L, -1577703810L, -1336129281L, 932347700L, 
1388621583L, -469043706L, -1285091933L, 640453283L, 514770224L, 
-1156521588L, -86366490L, -1078766074L, -1087762543L, -735096980L, 
-1549173331L, 816892173L, -342653233L, -2039460811L, -1027420128L, 
-1814111364L, -1060938959L, 742913848L, -2139704116L, 230763807L, 
-1217569767L, 1247650849L, 1817837178L, 33073098L, -1287214530L, 
1376096089L, 30555000L, 880234241L, -132679108L, 2023576024L, 
-1968308935L, 350896305L, -350546295L, -1339707523L, -1996986827L, 
-750069346L, 2019110153L, 2010507683L, 1499114858L, 1221034340L, 
-55201954L, -27009123L, -636257817L, 169507249L, 693898591L, 
760623720L, -909425639L, 1705754829L, -1313442647L, -1581135430L, 
16673697L, -1267958419L, 1332689002L, -1158926668L, 495721563L, 
244051347L, -1514183753L, -639815868L, -1781542556L, -692156919L, 
2051887294L, -1914122214L, -383356852L, 1622339695L, -592502599L, 
-556629257L, 532008048L, -281553887L, -768445151L, -352434666L, 
-571885303L, 1103352084L, 1688500531L, -1361078092L, 27286100L, 
-219582676L, 1144261085L, 175701629L, -326296560L, 505864082L, 
979434262L, -1459028703L, 1004276016L, -103691272L, -1380152717L, 
103978604L, 775878565L, -1512848713L, 1380214743L, 195416670L, 
-64905306L, -2061452680L, -2059069998L, 1751878340L, -901786959L, 
-1808832951L, 333730595L, 155051652L, -114136432L, -1792807040L, 
-669065844L, -40602418L, 1888486298L, 221740459L, -776216693L, 
-759007236L, -2107020284L, -1064059511L, 1282093151L, 1288083859L, 
828371778L, -477286234L, 1048762045L, -1964138693L, -986068094L, 
1702791140L, -701726756L, 1497120837L, 1341752833L, 1941426743L, 
679892623L, -69036935L, 1042913176L, -707092306L, 1778589148L, 
-1203408296L, 165002193L, 66663045L, -765673841L, -670037979L, 
-2061012313L, -521231938L, -1458748160L, 510890047L, 517006858L, 
-1106600160L, 1697798857L, 1374654699L, -1329524735L, 147765279L, 
-54923264L, 335215122L, -784761704L, 1008955615L, 2098139462L, 
-1490175118L, -1406571085L, -1152159470L, -2116290393L, 973135784L, 
-407846339L, 91247076L, -1270777129L, 520392520L, 935330501L, 
1214726339L, 1759434859L, 914695131L, 575876380L, 185113183L, 
-1803307715L, -787346694L, -1944422115L, -911950047L, -1974450029L, 
-484550235L, -735767970L, 419724140L, 82738512L, -21269283L, 
1481364191L, 2052612746L, 409598710L, 1375600209L, 1805068679L, 
-1218769587L, -430995374L, -743769972L, 1416344157L, -894912681L, 
-953784357L, 1226488055L, -1708139998L, 1098915931L, 753725969L, 
105943479L, 919752384L, -1394184458L, -2083022837L, 1142405617L, 
-852560090L, 1614587943L, -1632540004L, 782503124L, 1359511283L, 
1802420419L, 1518930069L, -889840683L, 1792387250L, 1628877863L, 
-1035409712L, 89630224L, -747760297L, -1930525421L, 437973357L, 
2002557563L, -258998554L, 2029350061L, -985002193L, -1149315111L, 
-955951243L, -1745906808L, -1189428597L, 1432303109L, 1133303885L, 
1318201162L, 42941320L, 1107944820L, -962571238L, 2137510837L, 
1129487240L, 1637756575L, 308593884L, -2004056331L, 94376351L, 
-1310829101L, -761732610L, -42306764L, -56685990L, -1178321163L, 
-1303085749L, 1671878345L, -936552788L, -867833460L, 704830697L, 
1174726580L, 1566560463L, -726527240L, 607730759L, 2044821405L, 
1683011630L, 1306045960L, 747348418L, -1995048319L, 67753504L, 
1850386365L, -878540578L, 2030985621L, 1599574666L, 1130707121L, 
-1061888609L, -1533811533L, -1686609013L, -1305465928L, -1793764883L, 
1366209685L, 1020821247L, 811945970L, 516856759L, 1645604082L, 
-723481138L, 2054878228L, 1055244342L, 1267906174L, -149484207L, 
1893026618L, 2066225108L, -636361509L, 1204288031L, 1808071176L, 
2123356843L, -164362183L, 1340310464L, 1494503539L, 1292431590L, 
-1679366373L, 1139788819L, 1979839436L, 1779548790L, 1524419541L, 
1626372886L, 527265140L, 743859962L, 1886786557L, 1414284343L, 
-1602009995L, -960203316L, 386460461L, 382314113L, 488058564L, 
54251097L, 731916569L, 1633358446L, 276561965L, 573497844L, -1825530218L, 
1468256900L, -274279787L, -2105979127L, -1383909277L, -921915299L, 
-2089059664L, -1207012329L, -814324213L, 1318809738L, 1428891438L, 
1125095688L, -2066055560L, -1483592116L, 19572403L, 1016215100L, 
1888612105L, 1756422121L, -1696848131L, 1474030445L, 1633672810L, 
-1452695056L, -2101447495L, 757317618L, 502427844L, 566802492L, 
-1780421717L, -59374165L, -678664992L, -828266472L, 323800610L, 
212389631L, -833994011L, -1850652137L, 2082431238L, 61751832L, 
1200193220L, 1602757833L, -767376574L, 1324433665L, -324293114L, 
2117710490L, 1488867325L, -572190665L, 1354671303L, -696552212L, 
644262991L, -1508628111L, 987826153L, -1036270614L, 1762206296L, 
1565511850L, -14802381L, -1861485218L, 1229093286L, 1980935575L, 
274036669L, 1233283696L, 1545561561L, -572038552L, 935617470L, 
-781247662L, 128028723L, -1692139865L, -1871557370L, -548746370L, 
5436478L, 1443402536L, -1287344844L, 1516714978L, 464400252L, 
-592344731L, -1954630241L, -236331062L, -1053459219L, -80375436L, 
1592667359L, 122837253L, -1336100918L, -100559412L, -403105056L, 
1312256341L, 1465149208L, -1752641116L, -1932836360L, -1699791064L, 
162207872L, 1206369594L, -238862102L, -1880708909L, 1448277362L, 
1280673216L, 1874847879L, -1656130043L, -1393676549L, 1262048917L, 
-545449244L, -1544360730L, -760106086L, -1824261011L, 974734731L, 
-686111072L, -1525639249L, -808643128L, -2016756407L)
